
rm(list = ls())

# install.packages()  #### to install new packages before opening them with 'library()'
#install.packages("ggExtra")
library(ggExtra)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(patchwork)
library(data.table)
library(ggpubr)
library(sf)
library(EnvStats)
# install.packages("tidyverse")


############## DROPLETS IMAGES - TIMEPOINTS ANALYSIS - PPU-PVE succinate - all rep ##############


### ===================================================
###        Import data frame + post-processing 
### ===================================================

# working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()

# import data frame
DropletsF = read.table(paste0(getwd(),"/Figure2&S2&S3&S17/results_plots/droplet_results.csv"), sep = "," , header = T)
summary(DropletsF)


### Calculate proportions of empty/non-empty droplets

# path to the appriopriate sub-script
script_path <- paste0(getwd(),"/Figure2&S2&S3&S17/scripts/sub_scripts/proportion_non_empty_droplets.R")
# Call and run the sub-script
source(script_path)


### Add 'mono/mix' column
DropletsF <- DropletsF %>% 
  mutate(NbSpecies = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 | Fluo1Sum > 0 & Fluo2Sum == 0 ~ "mono", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix"
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'PPU',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'PVE',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "PPU PVE"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "mix","medium")) # Add a 'factor' column to plot mono-culture before mix-culture


### Normalize both fluorescent signals based on median signal in mono-culture droplets

# Set productivity thresholds filter out 'non-growing' droplets in mono-cultures 
# when estimating the median productivity in mono-culture
threshold_pve <- 1
threshold_ppu <- 0.2

# Calculate median productivity in mono-cultures for each replicate
list.rep <- unique(DropletsF$BiologicalRep)
list.medians.ppu <- plyr::ldply(list.rep, function(r) {
  bio_rep <- r
  median.ppu <- median(DropletsF[which(DropletsF$Condition == 'Ppu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > threshold_ppu), 'Fluo2Sum'])
  df <- data.frame('BiologicalRep' = bio_rep,
                   'Median_PPU_mono' = median.ppu)
})
list.medians.pve <- plyr::ldply(list.rep, function(r) {
  bio_rep <- r
  median.pve <- median(DropletsF[which(DropletsF$Condition == 'Pve' & DropletsF$BiologicalRep == r & DropletsF$Fluo1Sum > threshold_pve), 'Fluo1Sum']) 
  df <- data.frame('BiologicalRep' = bio_rep,
                   'Median_PVE_mono' = median.pve)
})

# Normalize fluorescent signal for each replicate by the median
# of mono-cultures
# Normalize productivity by biological replicate
DropletsF <- DropletsF %>%
  left_join(list.medians.ppu, by = "BiologicalRep") %>%
  mutate(norm_fluo2 = Fluo2Sum / Median_PPU_mono)
DropletsF <- DropletsF %>%
  left_join(list.medians.pve, by = "BiologicalRep") %>%
  mutate(norm_fluo1 = Fluo1Sum / Median_PVE_mono)




### ==============================================================================================================
### Participation of 'solo' droplets and 'mix' droplets to each strain total productivity in co-culture emulsions
### ==============================================================================================================


list.rep <- unique(DropletsF$BiologicalRep)

list.solo.mix.proportion <- plyr::ldply(list.rep, function(r) {
  bio_rep <- r
  
  nb.solo.ppu <- length(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > 0 & DropletsF$Fluo1Sum == 0), 'Fluo2Sum'])
  sum.prod.solo.ppu <- sum(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > 0 & DropletsF$Fluo1Sum == 0), 'Fluo2Sum'])
  
  nb.solo.pve <- length(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo1Sum > 0 & DropletsF$Fluo2Sum == 0), 'Fluo1Sum'])
  sum.prod.solo.pve <- sum(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo1Sum > 0 & DropletsF$Fluo2Sum == 0), 'Fluo1Sum'])
  
  nb.mix <- length(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > 0 & DropletsF$Fluo1Sum > 0), 'Fluo2Sum'])
  sum.prod.mix.ppu <- sum(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > 0 & DropletsF$Fluo1Sum > 0), 'Fluo2Sum'])
  sum.prod.mix.pve <- sum(DropletsF[which(DropletsF$Condition == 'PvePpu' & DropletsF$BiologicalRep == r & DropletsF$Fluo2Sum > 0 & DropletsF$Fluo1Sum > 0), 'Fluo1Sum'])
  
  prop.solo.ppu <- nb.solo.ppu/(nb.solo.ppu + nb.mix)
  prop.solo.pve <- nb.solo.pve/(nb.solo.pve + nb.mix)
  
  prop.solo.ppu.prod <- sum.prod.solo.ppu/(sum.prod.solo.ppu + sum.prod.mix.ppu)
  prop.solo.pve.prod <- sum.prod.solo.pve/(sum.prod.solo.pve + sum.prod.mix.pve)
  
  df <- data.frame('BiologicalRep' = bio_rep,
                   'Nb_PPU_solo_droplets' = nb.solo.ppu,
                   'Nb_PVE_solo_droplets' = nb.solo.pve,
                   'Nb_mix_droplets' = nb.mix,
                   'Proportion_PPU_solo_drop' = prop.solo.ppu,
                   'Proportion_PVE_solo_drop' = prop.solo.pve,
                   'Sum_productivity_PPU_solo' = sum.prod.solo.ppu,
                   'Sum_productivity_PVE_solo' = sum.prod.solo.pve,
                   'Sum_productivity_PPU_mix' = sum.prod.mix.ppu,
                   'Sum_productivity_PVE_mix' = sum.prod.mix.pve,
                   'proportion_sumprod_PPU_solo' = prop.solo.ppu.prod,
                   'proportion_sumprod_PVE_solo' = prop.solo.pve.prod
  )
})

### ===================================================
###             STARTING CELL DISTRIBUTION
### ===================================================

initial_cell_nb <- DropletsF %>% filter(Timepoint == 'T0')

# Co-culture droplets
starting_cell_hist <- ggplot(initial_cell_nb %>% filter(Condition == 'PvePpu'), aes(x = NumberFluo2objects))+
  geom_histogram(binwidth = 1, color = 'Darkgreen', fill = 'darkseagreen3', alpha = 0.7 )+
  facet_grid(~BiologicalRep)+
  ggtitle('Starting P. putida cell distribution (OD=0.01)')+
  xlim(-1,12)+
  theme_bw()+
#  geom_histogram(aes(x = NumberFluo1objects), binwidth = 1, color = 'Magenta3', fill = 'plum2', alpha = 0.5 )
ggplot(initial_cell_nb %>% filter(Condition == 'PvePpu'), aes(x = NumberFluo1objects))+
  facet_grid(~BiologicalRep)+
  geom_histogram(binwidth = 1, color = 'Magenta3', fill = 'plum2', alpha = 0.7 )+
  ggtitle('Starting P. veronii cell distribution (OD=0.02)')+
  theme_bw()+
  xlim(-1,12)
starting_cell_hist

pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/FigS2_A_B.pdf'), width=8 , height=3)
starting_cell_hist
dev.off()


# R1
  bio_rep <- 'R1'
  start.celldf <- initial_cell_nb %>% filter(BiologicalRep == bio_rep)
  start.celldf$stat_cell_nb_ppu_pve <- paste0(start.celldf$NumberFluo2objects,':',start.celldf$NumberFluo1objects)
  start.combi1 <- data.frame('stat_cell_nb_ppu_pve' = unique(start.celldf$stat_cell_nb_ppu_pve),
                            'BiologicalRep' = bio_rep)
  start.combi1 <- start.combi1 %>% mutate(frequency = rep(NA, nrow(.)))
  
  for (i in start.combi1$stat_cell_nb_ppu_pve) {
    cell.nb <- i
    frequency <- nrow(start.celldf[which(start.celldf$stat_cell_nb_ppu_pve == cell.nb),])/nrow(start.celldf)
    start.combi1[which(start.combi1$stat_cell_nb_ppu_pve == cell.nb),]$frequency <- frequency
  }
  
  # R2
  bio_rep <- 'R2'
  start.celldf <- initial_cell_nb %>% filter(BiologicalRep == bio_rep)
  start.celldf$stat_cell_nb_ppu_pve <- paste0(start.celldf$NumberFluo2objects,':',start.celldf$NumberFluo1objects)
  start.combi2 <- data.frame('stat_cell_nb_ppu_pve' = unique(start.celldf$stat_cell_nb_ppu_pve),
                            'BiologicalRep' = bio_rep)
  start.combi2 <- start.combi2 %>% mutate(frequency = rep(NA, nrow(.)))
  
  for (i in start.combi2$stat_cell_nb_ppu_pve) {
    cell.nb <- i
    frequency <- nrow(start.celldf[which(start.celldf$stat_cell_nb_ppu_pve == cell.nb),])/nrow(start.celldf)
    start.combi2[which(start.combi2$stat_cell_nb_ppu_pve == cell.nb),]$frequency <- frequency
  }

  # R3
  bio_rep <- 'R3'
  start.celldf <- initial_cell_nb %>% filter(BiologicalRep == bio_rep)
  start.celldf$stat_cell_nb_ppu_pve <- paste0(start.celldf$NumberFluo2objects,':',start.celldf$NumberFluo1objects)
  start.combi3 <- data.frame('stat_cell_nb_ppu_pve' = unique(start.celldf$stat_cell_nb_ppu_pve),
                             'BiologicalRep' = bio_rep)
  start.combi3 <- start.combi3 %>% mutate(frequency = rep(NA, nrow(.)))
  
  for (i in start.combi3$stat_cell_nb_ppu_pve) {
    cell.nb <- i
    frequency <- nrow(start.celldf[which(start.celldf$stat_cell_nb_ppu_pve == cell.nb),])/nrow(start.celldf)
    start.combi3[which(start.combi3$stat_cell_nb_ppu_pve == cell.nb),]$frequency <- frequency
  }
  
# combine all three df  
start.combi <- rbind(start.combi1, start.combi2, start.combi3)
start.combi
# Use str_split to split the column
split_columns <- str_split(start.combi$stat_cell_nb_ppu_pve, ':', simplify = TRUE)
# Create new columns in your data frame
start.combi$start_ppu_cell <- as.numeric(split_columns[, 1])
start.combi$start_pve_cell <- as.numeric(split_columns[, 2])

# Create a heatmap
start_fr <- ggplot(start.combi, aes(x = start_ppu_cell, y = start_pve_cell, fill = frequency)) +
  facet_grid(~BiologicalRep)+
  geom_tile(color = "black",
            lwd = 0.25,
            linetype = 1)+
  scale_fill_gradient(low = 'grey99', high = 'brown4') +
  labs(title = "Starting cell number distribution",
       x = "P. putida",
       y = "P. veronii") +
  theme_bw() +
  theme(panel.grid = element_blank())+
  lims(x = c(-0.5, 7), y = c(-0.5, 7)); start_fr

pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/FigS2_C.pdf'), width=8 , height=3)
start_fr
dev.off()


### ===================================================
###        MIXED CULTURE - COMPARE REPLICATES
### ===================================================

### Compare technical replicates of R1
norm.mix.R1techrep <- ggplot(DropletsF %>% filter(Timepoint == "T24", Condition == "PvePpu", BiologicalRep == "R1", Fluo1Sum != 0, Fluo2Sum != 0), 
        aes(x = norm_fluo2, y = norm_fluo1)) +
    geom_jitter(col="dodgerblue3", alpha = 0.3)+
    theme_bw()+
    ggtitle("Productivity of P. putida and P. veronii in mixed droplet - all tech rep from R1 (24h)") +
    ylab("P. veronii productivity (mCHE - AF)")+
    xlab("P. putida productivity (GFP - AF)")+
    facet_grid(~TechnicalRep); norm.mix.R1techrep


pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/FigS17.pdf'), width=7 , height=4)
norm.mix.R1techrep
dev.off()

        ##### Nb: R1 contains 3 technical replicates (9 droplets pictures) compared to R2 and R3 which contain only 1 tech replicate (4 pictures each)



### NORMALIZED - PVE productivity vs PPU productivity in mix 
norm.mix.all.rep <- ggplot(DropletsF %>% filter(Timepoint == 'T24', TechnicalRep == "r1", NbSpecies == 'mix', Fluo1Sum != 0, Fluo2Sum != 0),
                      aes(x = norm_fluo2, y = norm_fluo1)) +
  geom_point(size = 2, alpha = 0.4, color = 'steelblue4')+
  geom_abline(intercept = 0, slope = 1, linetype = "dashed", color = "black")+  
  ylab("PVE - normalized productivity")+
  xlab("PPU - normalized productivity")+
  theme_bw()+
  xlim(0, 2)+
  ylim(0, 2)+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression('Co-cultures droplets (t = 24h)')); norm.mix.all.rep


pdf(paste0(getwd(),'/Figure7&S16/results_plots/Fig7_B.pdf'), width=5 , height=5)
norm.mix.all.rep
dev.off()

norm.mix.all.rep2 <- ggplot(DropletsF %>% filter(Timepoint == 'T24', TechnicalRep == "r1", NbSpecies == 'mix', Fluo1Sum != 0, Fluo2Sum != 0),
                           aes(x = norm_fluo2, y = norm_fluo1, color = BiologicalRep)) +
  geom_point(size = 2, alpha = 0.4)+
  ylab("PVE - normalized productivity")+
  xlab("PPU - normalized productivity")+
  geom_abline(intercept = 0, slope = 1, color = "black", linetype = "dashed")+ # linetype = "dashed", 
  #geom_vline(xintercept = 0.025, linetype = "dashed", color = "blue") +
  theme_bw()+
  xlim(0, 2)+
  ylim(0, 2)+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression('Co-cultures droplets (t = 24h)')); norm.mix.all.rep2


pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/Fig2_G.pdf'), width=6.25 , height=5)
norm.mix.all.rep2
dev.off()


## Proportion of PVE dominating droplets
point_above_diagonal <- DropletsF %>% filter(Timepoint == 'T24', TechnicalRep == "r1", NbSpecies == 'mix', Fluo1Sum != 0, Fluo2Sum != 0, norm_fluo1 > norm_fluo2)

list.rep <- unique(DropletsF$BiologicalRep)

nb.PVE.dominant <- plyr::ldply(list.rep, function(r) { 
  rep.df <- point_above_diagonal %>% filter(BiologicalRep == r)
  rep.whole <- DropletsF %>% filter(Timepoint == 'T24', BiologicalRep == r, TechnicalRep == "r1", NbSpecies == 'mix', Fluo1Sum != 0, Fluo2Sum != 0)
  nb.dom <- nrow(rep.df)
  nb.total.rep <- nrow(rep.whole)
  prop_dom <- nb.dom / nb.total.rep
  df <- data.frame('BiologicalRep' = r,
                   'Proportion_PVE_dominant' = prop_dom)
  return(df)
})

# save table
write_csv(nb.PVE.dominant, paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/proportion_PVE_dominant_Fig2G.csv'))

rm("rep.df", "rep.whole", "nb.dom", "nb.total.rep", "prop_dom")
# mean proportion of PVE dominant droplets + sd
mean(nb.PVE.dominant$Proportion_PVE_dominant)
sd(nb.PVE.dominant$Proportion_PVE_dominant)

### ===================================================
###                 MONO VS CO-CULTURES
### ===================================================


#### Next, compare the productivity of putida vs veronii in mono-culture vs co-culture. Display also the mono-cultures droplets from both batches of droplets (mono and mixed)

### Add a new "Condition" column to distinguish mono-species droplets of the mono-cultures and the co-cultures batches
### Note that the sub set of data created here doesn't include empty droplets
Ppu_Mono <- DropletsF %>% filter(Condition=="Ppu" & Fluo1Sum==0 & Fluo2Sum!=0) %>% 
  mutate(Condition2 = "Ppu mono") #putida alone - monoculture batch
Ppu_MonoFromMix <- DropletsF %>% filter(Condition=="PvePpu" & Fluo1Sum == 0 & Fluo2Sum != 0) %>% 
  mutate(Condition2 = "Ppu mono from mix") #putida alone - co-culture batch
Pve_Ppu <- DropletsF %>% filter(Condition=="PvePpu" & Fluo1Sum != 0 & Fluo2Sum != 0) %>% 
  mutate(Condition2 = "Pve Ppu") #putida and veronii mixed
Pve_Mono <- DropletsF %>% filter(Condition=="Pve" & Fluo1Sum!=0 & Fluo2Sum==0) %>% 
  mutate(Condition2 = "Pve mono") #veronii alone - monoculture batch
Pve_MonoFromMix <- DropletsF %>% filter(Condition=="PvePpu" & Fluo1Sum != 0 & Fluo2Sum == 0) %>% 
  mutate(Condition2 = "Pve mono from mix") #veronii alone - co-culture batch
MediumOnly <- DropletsF %>% filter(Condition=="C21") %>% 
  mutate(Condition2 = "medium only")
### Concatenate in one table with the new "condition" column
FilteredDroplets <- rbind(Ppu_Mono, Ppu_MonoFromMix, Pve_Ppu, Pve_Mono, Pve_MonoFromMix, MediumOnly)

### Add 'mono/mix' column
FilteredDroplets2 <- FilteredDroplets %>% 
  mutate(CultureCondition = case_when(
    Condition2 == "Ppu mono" | Condition2 == "Pve mono" ~ "mono", 
    Condition2 == "medium only" ~ "medium",
    Condition2 == "Pve Ppu" ~ "mix"
  ))
# Add a 'factor' column to plot mono-culture before mix-culture
FilteredDroplets2 <- FilteredDroplets2 %>%
  mutate(factor = fct_relevel(CultureCondition, "mono", "mix"))



### ===========================================================
### P. putida productivity - mono-culture vs co-culture (24h)
### ===========================================================



# normalized productivity fluorescence signal
Pp.norm <- ggplot(FilteredDroplets %>% filter(Timepoint == "T24", Condition2 == "Ppu mono" | Condition2 =="Ppu mono from mix" | Condition2 =="Pve Ppu"),
       aes(x=Condition2, y=norm_fluo2))+
  geom_jitter(height = 0, col="Darkgreen", alpha = 0.3)+
  geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
  facet_grid(~BiologicalRep)+
  ylab("Normalized productivity (Area x Fluorescene)")+
  xlab("Culture condition")+
  ylim(-0.5,4)+
  stat_n_text(size=6)+
  theme_bw()+
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
  ggtitle(expression(italic("P. putida") ~ " (24h)")); Pp.norm


pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/Fig2_E_left.pdf'), width=7 , height=5)
Pp.norm
dev.off()


### ===========================================================
### P. veronii productivity - mono-culture vs co-culture (24h)
### ===========================================================


# normalized productivity fluorescence signal
Pv.norm <- ggplot(FilteredDroplets %>% filter(Timepoint == "T24", Condition2 == "Pve mono" | Condition2 =="Pve mono from mix" | Condition2 =="Pve Ppu"),
        aes(x=Condition2, y=norm_fluo1))+
    geom_jitter(height = 0, col="Magenta3", alpha = 0.3)+
    geom_violin(draw_quantiles = c(0.25, 0.5, 0.75), alpha = 0.1)+
    facet_grid(~BiologicalRep)+
    #stat_summary(fun = "median", geom = "crossbar", color="violetred3")+
    ylab("Normalized productivity (Area x Fluorescene)")+
    xlab("Culture condition")+
    stat_n_text(size=6)+
    theme_bw()+
    theme(axis.text.y = element_text(colour="black"))+
    theme(axis.text.x = element_text(colour="black"))+
    theme(axis.text = element_text(size=21), axis.title = element_text(size=16), strip.text = element_text(size=16), plot.title = element_text(size = 18))+
    ggtitle(expression(italic("P. veronii") ~ " (24h)")); Pv.norm

pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/Fig2_E_right.pdf'), width=7 , height=5)
Pv.norm
dev.off()











