
rm(list = ls())

# install.packages()  #### to install new packages before opening them with 'library()'
library(ggplot2)
library(tidyverse)
library(patchwork)
library(data.table)
library(ggpubr)
library(dplyr)
library(ggExtra)
library(EnvStats)


      ############## Flow-cytometry counting - droplets and 96 well plates ##############
                       ##############  SUCCINATE 10mM  ##############


### ======================================================================
###  IMPORT DROPLETS DATA FRAMES - PROPORTION OF EMPTY/NON EMPTY DROPLETS
### ======================================================================


# Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()


# import droplet data frame
DropletsF = read.table(paste0(getwd(),"/Raw_data/flow_cytometry/PPU-PVE_10mM succinate/droplet_results.csv"), sep = "," , header = T)
summary(DropletsF)

# Set the path to the sub-script that will use the loaded DropletsF data frame
# (result of the analysis of droplets microscopy images) to assess the 
# proportions of empty/non-empty droplets. These proportions will 
# be used to adjust the measured concentration of cells by flow cytometry on
# the total volume of fused droplets.
script_path <- paste0(getwd(),"/Figure2&S2&S3&S17/scripts/sub_scripts/proportion_non_empty_droplets.R")
# Call and run the sub-script
source(script_path)


### ======================================================================
###          IMPORT FLOW CYTOMETRY DATA FRAME + POST PROCESSING
### ======================================================================


# Import FC counting table
fc_table <- read.table(paste0(getwd(),"/Raw_data/flow_cytometry/PPU-PVE_10mM succinate/FC_counting_all_results.csv"), sep = ";" , header = T)

# post processing script
script_path2 <- paste0(getwd(),"/Figure2&S2&S3&S17/scripts/sub_scripts/fc_counting_post_processing.R")

# Call and run the sub-script
source(script_path2)


# Calculate means cell concentrations per technical replicate
mean.tech.rep <- cell_conc %>%                                       
  group_by(Culture, Condition, BioRep, TechRep, DilutionFactor, channel) %>%                         
  summarise_at(vars(CellConcentration),             
               list(Mean.concentration = mean))

# Calculate means cell concentrations per biological replicate
mean.bio.rep <- mean.tech.rep %>%                                       
  group_by(Culture, Condition, BioRep, DilutionFactor, channel) %>%                         
  summarise_at(vars(Mean.concentration),             
               list(Mean.concentration.biorep = mean))
# save per replicate-ratios table
write.csv(mean.bio.rep, paste0(getwd(),'/Figure8&S12-S14/results_plots/fc_counts_smalldroplets_ratios_table.csv'), row.names = FALSE)


# calculate mean yields
mean.all.rep.conditions <- mean.bio.rep %>%                                       
  group_by(Culture, Condition, DilutionFactor, channel) %>%                         
  summarise_at(vars(Mean.concentration.biorep),             
               list(Mean.final = mean,
                    sd.final = sd))
mean.all.rep.conditions$sd.final2 <- mean.all.rep.conditions$sd.final / mean.all.rep.conditions$Mean.final
mean.final.pp <- mean.all.rep.conditions %>% filter(DilutionFactor == 3, channel == 'GFP')
mean.final.pv <- mean.all.rep.conditions %>% filter(DilutionFactor == 3, channel == 'mCherry')

# ratio prod mix/mono
ratio_pp <- mean.final.pp[which(mean.final.pp$Culture=='plate'&mean.final.pp$Condition=='PpPv'),]$Mean.final/mean.final.pp[which(mean.final.pp$Culture=='plate'&mean.final.pp$Condition=='Ppu'),]$Mean.final; ratio_pp

ratio_pv <- mean.final.pv[which(mean.final.pv$Culture=='plate'&mean.final.pv$Condition=='PpPv'),]$Mean.final/mean.final.pv[which(mean.final.pv$Culture=='plate'&mean.final.pv$Condition=='Pve'),]$Mean.final; ratio_pv

ratio_pvmix_drop_plate <- mean.final.pv[which(mean.final.pv$Culture=='droplet'&mean.final.pv$Condition=='PpPv'),]$Mean.final/mean.final.pv[which(mean.final.pv$Culture=='plate'&mean.final.pv$Condition=='PpPv'),]$Mean.final; ratio_pvmix_drop_plate

# STATISTICS
mean.rep.ppu.mono.pl <- mean.bio.rep %>% filter(channel=='GFP'&Culture=='plate'&DilutionFactor==3 &Condition=='Ppu')
mean.rep.ppu.mix.pl <- mean.bio.rep %>% filter(channel=='GFP'&Culture=='plate'&DilutionFactor==3 &Condition=='PpPv')
mean.rep.pve.mono.pl <- mean.bio.rep %>% filter(channel=='mCherry'&Culture=='plate'&DilutionFactor==3 &Condition=='Pve')
mean.rep.pve.mix.pl <- mean.bio.rep %>% filter(channel=='mCherry'&Culture=='plate'&DilutionFactor==3 &Condition=='PpPv')
  # normality shapiro test
shapiro.test(mean.rep.ppu.mono.pl$Mean.concentration.biorep)
shapiro.test(mean.rep.ppu.mix.pl$Mean.concentration.biorep)
shapiro.test(mean.rep.pve.mono.pl$Mean.concentration.biorep)
shapiro.test(mean.rep.pve.mix.pl$Mean.concentration.biorep)

### ======================================================================
###                 PLOT DATA - FRAGMENTED VS SUSPENSION
### ======================================================================


# Create a mono-mix column
mean.bio.rep <- mean.bio.rep %>%
  mutate(species = case_when(
    Condition == 'Ppu' | Condition == 'Pve' ~ 'mono',
    Condition == 'PpPv' ~ 'mix',
    Condition == 'med' ~ 'medium'
  ))
# Add a 'factor' column to plot mono-culture before mix-culture
mean.bio.rep <- mean.bio.rep %>%
  mutate(factor = fct_relevel(species, "mono", "mix"))

summary(mean.bio.rep)


# Save in pdf
pdf(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/Fig2_C_D.pdf'), height = 5, width = 8.5)

ggplot(mean.bio.rep %>% filter(channel == 'GFP', DilutionFactor == 3, Condition == 'Ppu' | Condition == 'PpPv'),
       aes(x = factor, y = Mean.concentration.biorep)) +
  geom_boxplot(col = 'Darkgreen')+
  geom_jitter(col='forestgreen', alpha=0.5) +
  stat_compare_means(method = "t.test") +###
  scale_y_log10(
    limits=c(1.0e+07, 9.0e+09),
    breaks = c(1.0e+07,1.0e+08,1.0e+09,1.0e+10),
    labels = scales::trans_format("log10", scales::math_format(10^.x)))+
  facet_grid(~ Culture) +
  theme_bw() +
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  ggtitle(expression(italic("P. putida") ~ " (24h)")) +
  ylab('Cells/ml') +
  xlab('Culture condition') +
  theme(axis.text = element_text(size=20), axis.title = element_text(size=20), strip.text = element_text(size=18),
        plot.title = element_text(size = 18))+
  
  # PVE
  ggplot(mean.bio.rep %>% filter(channel == 'mCherry', DilutionFactor == 3, Condition == 'Pve' | Condition == 'PpPv'), 
         aes(x = factor, y = Mean.concentration.biorep)) +
  geom_boxplot(col = 'magenta4')+ #deeppink4
  geom_jitter(col='magenta3', alpha=0.5) +
  stat_compare_means(method = "t.test") + ###
  scale_y_log10(
    limits=c(1.0e+07, 9.0e+09), 
    breaks = c(1.0e+07,1.0e+08,1.0e+09,1.0e+10),
    labels = scales::trans_format("log10", scales::math_format(10^.x)))+
  facet_grid(~ Culture) +
  theme_bw() +
  theme(axis.text.y = element_text(colour="black"))+
  theme(axis.text.x = element_text(colour="black"))+
  ggtitle(expression(italic("P. veronii") ~ " (24h)")) +
  ylab('Cells/ml') + 
  xlab('Culture condition') +
  theme(axis.text = element_text(size=20), axis.title = element_text(size=20), strip.text = element_text(size=18),
        plot.title = element_text(size = 18))

dev.off()




