
rm(list = ls())

library(ggplot2)
library(tidyverse)
library(readxl)
library(dplyr)
library(ggpubr)


## Data preparation

# Before being imported, the well names table was manually created (see 96-well plan scheme file), and OD_GFP_mCherry_curves.xlsx file was manually created by separating the different tables (OD600, gfp and mCherry fluorescence measurements) into separated excel sheet, from the excel files contained in the raw data folder.

### Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()


# Import well-names table
well_names <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/microplate_well_annotation.xlsx')



# Split the tables per plate. Replicate 1 was cultured on one 96-well plate, while Replicates 2 and 3 were cultured in parallel on the same plate.
R1_wells <- well_names %>% filter(BioRep == 'R1')
R2R3_wells <- well_names %>% filter(BioRep == 'R2' | BioRep == 'R3')

# Import data
R1_OD <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 1)
R2R3_OD <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 4)

head(R1_wells)
head(R1_OD)

head(R2R3_wells)
head(R2R3_OD)


### Measurements were made every 30 minutes.
# Time step
time_step <- 30 # one measurement every 30 minutes



### Once the time-step has been defined, create a 'time' column with the timepoints in the proper unit (hour unit). Then remove the original 'Time' column which contains both hour and date.

# R1 - OD600 signal
R1_OD <- R1_OD %>% 
  mutate(time = seq(1:nrow(R1_OD)))
R1_OD$time <- R1_OD$time*time_step/60 # convert into hours
R1_OD <- R1_OD[,!(names(R1_OD) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R1_OD$time[1], ' hours'))
print(paste0('final time step = ', R1_OD$time[length(R1_OD$time)], ' hours'))


# R2 and R3 - OD600 signal
R2R3_OD <-R2R3_OD %>% 
  mutate(time = seq(1:nrow(R2R3_OD)))
R2R3_OD$time <- R2R3_OD$time*time_step/60 # convert into hours
R2R3_OD <- R2R3_OD[,!(names(R2R3_OD) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R2R3_OD$time[1], ' hours'))
print(paste0('final time step = ', R2R3_OD$time[length(R2R3_OD$time)], ' hours'))


### Pivot dataframe to 'long' format and fuse both plate dataframes


# Change to long dataframe format
R1_OD <- R1_OD %>% 
  pivot_longer(
    cols = colnames(R1_OD[,1]):colnames(R1_OD[,ncol(R1_OD)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "OD_signal")

R2R3_OD <- R2R3_OD %>% 
  pivot_longer(
    cols = colnames(R2R3_OD[,1]):colnames(R2R3_OD[,ncol(R2R3_OD)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "OD_signal")


# add plate id
R1_OD <- R1_OD %>% mutate(plate_id = 1)
R2R3_OD <- R2R3_OD %>% mutate(plate_id = 2)

# Concatenate dataframes
OD_growth <- rbind(R1_OD, R2R3_OD) %>% 
  mutate(well_name =  rep(NA, nrow(.)))


### Now we add the associated well name column (and thereby annotate which condition it corresponds to) to each well-ID.

OD_growth2 = OD_growth
well_names2 = well_names

# Make a merged plate ID and well ID column
OD_growth2$mergecol_id = paste0(OD_growth2$plate_id, "_", OD_growth2$well_ID)
well_names2$mergecol_id = paste0(well_names$plate_id, "_", well_names$well_ID)

# Then associate well names to each merged plate and well ID
for (n in well_names2$mergecol_id) {
  
  OD_growth2[which(OD_growth2$mergecol_id == n), 'well_name'] <- well_names2[well_names2$mergecol_id == n,'well_name']
  
}



### Split well name information into sub columns


OD_growth2 <- OD_growth2 %>% separate(well_name, c('bio_replicate', 'Condition', 'tech_replicate'))

# save the two data frames for further analysis
write.csv(OD_growth2,'Figure2&S2&S3&S17/results_plots/OD600_growth.csv')


# Plot growth curves

g_pve <- ggplot(OD_growth2 %>% filter(Condition == 'Pve'), 
                aes(x = time, y = OD_signal, group = mergecol_id, color = Condition))+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'grey10')+
  geom_line(data = OD_growth2 %>% filter(Condition == 'PpuPve'), alpha=0.5, linewidth = 0.8, color = 'grey70')+
  xlab('time (h)')+
  ylab('OD600')+
  ggtitle("P. veronii - 10 mM succinate")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))
g_pve

g_ppu <- ggplot(OD_growth2 %>% filter(Condition == 'Ppu'), 
                aes(x = time, y = OD_signal, group = mergecol_id, color = Condition))+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'grey10')+
  geom_line(data = OD_growth2 %>% filter(Condition == 'PpuPve'), alpha=0.5, linewidth = 0.8, color = 'grey70')+
  xlab('time (h)')+
  ylab('OD600')+
  ggtitle("P. putida - 10 mM succinate")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10))
g_ppu

p_curves <- ggarrange(g_ppu, g_pve,
                      ncol = 1,
                      nrow = 2,
                      widths = c(4,4),
                      align = "h",
                      common.legend = TRUE)
p_curves

# save plot
ggsave(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/FigS3.pdf'), plot = p_curves, width = 8,
       height = 5.5)



