

rm(list = ls())

library(ggplot2)
library(tidyverse)
library(readxl)
library(dplyr)
library(ggpubr)


## Load package and data


### Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()



## Data preparation

# Before being imported, the well names table was manually created (see 96-well plan scheme file), and OD_GFP_mCherry_curves.xlsx file was manually created by separating the different tables (OD600, gfp and mCherry fluorescence measurements) into separated excel sheet, from the excel files contained in the raw data folder.


# Import well-names table
well_names <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/microplate_well_annotation.xlsx')

# Split the tables per plate. Replicate 1 was cultured on one 96-well plate, while Replicates 2 and 3 were cultured in parallel on the same plate.

R1_wells <- well_names %>% filter(BioRep == 'R1')
R2R3_wells <- well_names %>% filter(BioRep == 'R2' | BioRep == 'R3')

# Import data
R1_gfp <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 2)
R1_mch <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 3)
R2R3_gfp <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 5)
R2R3_mch <- read_excel('Raw_data/microplate_reader/microplate_reader_PPU_PVE/succinate 10mM/OD_GFP_mCherry_curves.xlsx', sheet = 6)

head(R1_wells)
head(R1_gfp)

head(R2R3_wells)
head(R2R3_gfp)


### Measurements were made every 30 minutes.

# Time step
time_step <- 30 # one measurement every 30 minutes



# Once the time-step has been defined, create a 'time' column with the timepoints in the proper unit (hour unit). Then remove the original 'Time' column which contains both hour and date.

# R1 - gfp signal
R1_gfp <- R1_gfp %>% 
  mutate(time = seq(1:nrow(R1_gfp)))
R1_gfp$time <- R1_gfp$time*time_step/60 # convert into hours
R1_gfp <- R1_gfp[,!(names(R1_gfp) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R1_gfp$time[1], ' hours'))
print(paste0('final time step = ', R1_gfp$time[length(R1_gfp$time)], ' hours'))

# R1 - mCherry signal
R1_mch <- R1_mch %>% 
  mutate(time = seq(1:nrow(R1_mch)))
R1_mch$time <- R1_mch$time*time_step/60 # convert into hours
R1_mch <- R1_mch[,!(names(R1_mch) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R1_mch$time[1], ' hours'))
print(paste0('final time step = ', R1_mch$time[length(R1_mch$time)], ' hours'))

# R2 and R3 - gfp signal
R2R3_gfp <-R2R3_gfp %>% 
  mutate(time = seq(1:nrow(R2R3_gfp)))
R2R3_gfp$time <- R2R3_gfp$time*time_step/60 # convert into hours
R2R3_gfp <- R2R3_gfp[,!(names(R2R3_gfp) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R2R3_gfp$time[1], ' hours'))
print(paste0('final time step = ', R2R3_gfp$time[length(R2R3_gfp$time)], ' hours'))

# R2 and R3 - mCherry signal
R2R3_mch <- R2R3_mch %>% 
  mutate(time = seq(1:nrow(R2R3_mch)))
R2R3_mch$time <- R2R3_mch$time*time_step/60 # convert into hours
R2R3_mch <- R2R3_mch[,!(names(R2R3_mch) %in% c('Time'))] # remove Time column
print(paste0('initial time step = ', R2R3_mch$time[1], ' hours'))
print(paste0('final time step = ', R2R3_mch$time[length(R2R3_mch$time)], ' hours'))


### Pivot dataframe to 'long' format and fuse both plate dataframes

# Change to long dataframe format
R1_gfp <- R1_gfp %>% 
  pivot_longer(
    cols = colnames(R1_gfp[,1]):colnames(R1_gfp[,ncol(R1_gfp)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "gfp_signal")

R1_mch <- R1_mch %>% 
  pivot_longer(
    cols = colnames(R1_mch[,1]):colnames(R1_mch[,ncol(R1_mch)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "mCherry_signal")

R2R3_gfp <- R2R3_gfp %>% 
  pivot_longer(
    cols = colnames(R2R3_gfp[,1]):colnames(R2R3_gfp[,ncol(R2R3_gfp)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "gfp_signal")

R2R3_mch <- R2R3_mch %>% 
  pivot_longer(
    cols = colnames(R2R3_mch[,1]):colnames(R2R3_mch[,ncol(R2R3_mch)-1]), # pivot to long format for the first to the for-last columns
    names_to = "well_ID",
    values_to = "mCherry_signal")

# add plate id
R1_gfp <- R1_gfp %>% mutate(plate_id = 1)
R1_mch <- R1_mch %>% mutate(plate_id = 1)
R2R3_gfp <- R2R3_gfp %>% mutate(plate_id = 2)
R2R3_mch <- R2R3_mch %>% mutate(plate_id = 2)

# Concatenate dataframes
gfp_growth <- rbind(R1_gfp, R2R3_gfp) %>% 
  mutate(well_name =  rep(NA, nrow(.)))
mch_growth <- rbind(R1_mch, R2R3_mch) %>% 
  mutate(well_name =  rep(NA, nrow(.)))



### Now we add the associated well name column (and thereby annotate which condition it corresponds to) to each well-ID.


gfp_growth2 = gfp_growth
mch_growth2 = mch_growth
well_names2 = well_names

# Make a merged plate ID and well ID column
gfp_growth2$mergecol_id = paste0(gfp_growth2$plate_id, "_", gfp_growth2$well_ID)
mch_growth2$mergecol_id = paste0(mch_growth2$plate_id, "_", mch_growth2$well_ID)
well_names2$mergecol_id = paste0(well_names$plate_id, "_", well_names$well_ID)

# Then associate well names to each merged plate and well ID
for (n in well_names2$mergecol_id) {
  
  gfp_growth2[which(gfp_growth2$mergecol_id == n), 'well_name'] <- well_names2[well_names2$mergecol_id == n,'well_name']
  
  mch_growth2[which(mch_growth2$mergecol_id == n), 'well_name'] <- well_names2[well_names2$mergecol_id == n,'well_name']
}

# left_join(gfp_growth2, well_names2, by="mergecol_id")


### Split well name information into sub columns


gfp_growth2 <- gfp_growth2 %>% separate(well_name, c('bio_replicate', 'Condition', 'tech_replicate'))
mch_growth2 <- mch_growth2 %>% separate(well_name, c('bio_replicate', 'Condition', 'tech_replicate'))

# save the two data frames for further analysis
write.csv(gfp_growth2,'Figure2&S2&S3&S17/results_plots/gfp_growth.csv')
write.csv(mch_growth2,'Figure2&S2&S3&S17/results_plots/mch_growth.csv')


### Plot growth curves

g_pve <- ggplot(mch_growth2 %>% filter(Condition == 'Pve'), 
                aes(x = time, y = mCherry_signal, group = mergecol_id, color = Condition))+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Magenta4')+
  geom_line(data = mch_growth2 %>% filter(Condition == 'PpuPve'), alpha=0.5, linewidth = 0.8, color = 'Plum2')+
  xlab('time (h)')+
  ylab('mcherry - Fluorescence')+
  ggtitle("P. veronii - 10 mM succinate")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10)); g_pve

g_ppu <- ggplot(gfp_growth2 %>% filter(Condition == 'Ppu'), 
                aes(x = time, y = gfp_signal, group = mergecol_id, color = Condition))+
  #geom_line( alpha=0.5, linewidth = 0.8)+
  facet_grid(~bio_replicate)+
  geom_line(alpha=0.5, linewidth = 0.8, color = 'Darkgreen')+
  geom_line(data = gfp_growth2 %>% filter(Condition == 'PpuPve'), alpha=0.5, linewidth = 0.8, color = 'yellow4')+
  xlab('time (h)')+
  ylab('gfp - Fluorescence')+
  ggtitle("P. putida - 10 mM succinate")+
  theme_bw()+
  theme(plot.title = element_text(size=10),
        axis.title = element_text(size = 10), 
        axis.text = element_text(size = 10)); g_ppu

p_curves <- ggarrange(g_ppu, g_pve,
                      ncol = 1,
                      nrow = 2,
                      widths = c(4,4),
                      align = "h",
                      common.legend = TRUE); p_curves

# save plot
ggsave(paste0(getwd(),'/Figure2&S2&S3&S17/results_plots/Fig2A.pdf'), plot = p_curves, width = 8,
       height = 5.5,)

